pub struct AssocItemList { /* private fields */ }Implementations
Sourceimpl AssocItemList
impl AssocItemList
pub fn assoc_items(&self) -> AstChildren<AssocItem> ⓘ
pub fn l_curly_token(&self) -> Option<SyntaxToken<RustLanguage>>
pub fn r_curly_token(&self) -> Option<SyntaxToken<RustLanguage>>
Sourceimpl AssocItemList
impl AssocItemList
Sourcepub fn add_items(&self, editor: &SyntaxEditor, items: Vec<AssocItem>)
pub fn add_items(&self, editor: &SyntaxEditor, items: Vec<AssocItem>)
Adds a new associated item after all of the existing associated items.
Attention! This function does align the first line of item with respect to self,
but it does not change indentation of other lines (if any).