Comment

Struct Comment 

pub struct Comment { /* private fields */ }

Implementations

Source

impl Comment

pub fn kind(&self) -> CommentKind

pub fn is_doc(&self) -> bool

pub fn is_inner(&self) -> bool

pub fn is_outer(&self) -> bool

pub fn prefix(&self) -> &'static str

pub fn doc_comment(&self) -> Option<(&str, TextSize)>

Returns the textual content of a doc comment node as a single string with prefix and suffix removed, plus the offset of the returned string from the beginning of the comment.